#!/bin/bash

RIGHT_VENDOR="
mesa
vivante
pvr"

STR="/usr/lib/gl4es"
PATH_GLVND_VENDOR="/usr/share/glvnd/egl_vendor.d"
PATH_LD_SO_CONF="/etc/ld.so.conf"
LIST_GLVND_VENDORS=$(ls ${PATH_GLVND_VENDOR})

function info_exit() {
	print_info
	exit 1
}

function message_print() {

	if [[ -z $MUTE ]]; then
		echo ${1}
	fi
}

function print_info() {

        echo "Параметры запуска:${RIGHT_VENDOR}
-m или -mute    Без вывода сообщений
-h или --help   Вывести справку и завершить работу"
}

function check_valid_vendor() {

	local VENDOR=$(find ${PATH_GLVND_VENDOR} -name ${1})
        if [[ -z $VENDOR ]]; then
                message_print "Нет вендора для ${1:1:-5} в системе"
                exit 1 
        fi
}

function take_name() {

	echo $(basename `find ${PATH_GLVND_VENDOR} -name ${1}`)
}

function rename_vendor_file() {

	local NUMBER=${1:0:2}
	local NAME=${1:3}
	if [[ $2 == up ]]; then
		message_print "Up ${1} to 30_${NAME}"
		mv ${PATH_GLVND_VENDOR}/${1} ${PATH_GLVND_VENDOR}/30_${NAME}

	else
		message_print "Down ${1} to 50_${NAME}"
		mv ${PATH_GLVND_VENDOR}/${1} ${PATH_GLVND_VENDOR}/50_${NAME}

	fi
}

function addgl4es() {

	if [[ -n `grep "#${STR}" ${PATH_LD_SO_CONF}` ]]; then
		sed -i "s%#${STR}%${STR}%g" ${PATH_LD_SO_CONF}
		message_print "Add ${STR} in ${PATH_LD_SO_CONF}"

	elif [[ -z `grep "${STR}" ${PATH_LD_SO_CONF}` ]]; then
		sed -i "1s%^%${STR}\n%" ${PATH_LD_SO_CONF}
		message_print "Add ${STR} in ${PATH_LD_SO_CONF}"

	else
		return
	fi

	ldconfig &> /dev/null
}

function delgl4es() {

	if [[ -n `grep "#${STR}" ${PATH_LD_SO_CONF}` ]]; then
                return

	elif [[ -z `grep "${STR}" ${PATH_LD_SO_CONF}` ]]; then
		return

	elif [[ -n `grep "${STR}" ${PATH_LD_SO_CONF}` ]]; then
		sed -i "s%${STR}%#${STR}%g" ${PATH_LD_SO_CONF}
		message_print "The line ${STR} is commented out in $PATH_LD_SO_CONF"
	fi

	ldconfig &> /dev/null
}

function run() {

	check_valid_vendor *${1}.json
	local UPVENDOR=$(take_name *${1}.json)
	local FIRST=$(echo ${LIST_GLVND_VENDORS} | awk '{print $1;}')

	if [[ ${UPVENDOR} != ${FIRST} ]]; then
		rename_vendor_file ${UPVENDOR} up
		rename_vendor_file ${FIRST} down
	fi

	if [[ ${1} == "mesa-pvr" ]]; then
		addgl4es
	else
		delgl4es
	fi
}

#main

if [[ $# == 0 ]]; then
	info_exit
fi

VENDOR=""

while  [ -n "${1}" ]
do
	case ${1} in
		mesa|mesa-pvr|vivante) VENDOR=${1};;
		pvr) VENDOR=mesa-pvr;;
		-m|-mute) MUTE=1;;
		--help|-h) print_info
			   exit 0;;
		*) echo "${1} нет такой опции/параметра"
		   info_exit
	esac
	shift
done

if [ -z ${VENDOR} ]; then
	info_exit
fi

run ${VENDOR}
